@@ -235,7 +235,7 @@ main(int argc, char **argv)
   putenv(g_strdup_printf("GTK_IM_MODULE_FILE=%/Contents/Resourcess/lib/gtk-3.0/3.0.0/immodules.cache", app_dir));
 
   if(getenv("GTK_THEME") == NULL){
-    putenv(g_strdup("GTK_THEME=Blackbird"));
+    putenv(g_strdup("GTK_THEME=Blue-Submarine"));
   }
 
   putenv(g_strdup_printf("GST_PLUGIN_SYSTEM_PATH=%s/lib/gstreamer-1.0", app_dir));
