@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2020 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -2572,6 +2572,10 @@ ags_thread_real_clock(AgsThread *thread)
       
     /* run task launcher */
     ags_task_launcher_sync_run(task_launcher);
+
+    if(task_launcher != NULL){
+      g_object_unref(task_launcher);
+    }
     
     /* signal */
 #if 1
@@ -2621,6 +2625,8 @@ ags_thread_real_clock(AgsThread *thread)
     }
 
     g_mutex_unlock(&(task_launcher->wait_mutex));
+
+    g_object_unref(task_launcher);
   }
   
   /* compute clocked steps */
@@ -2652,6 +2658,10 @@ ags_thread_real_clock(AgsThread *thread)
   if(thread == main_loop){
     ags_main_loop_set_critical_region(AGS_MAIN_LOOP(main_loop), FALSE);
   }
+
+  if(main_loop != NULL){
+    g_object_unref(main_loop);
+  }
   
   return(clocked_steps);
 }
@@ -2874,6 +2884,10 @@ ags_thread_loop(void *ptr)
     /* run task launcher */
     ags_task_launcher_sync_run(task_launcher);
 
+    if(task_launcher != NULL){
+      g_object_unref(task_launcher);
+    }
+    
     /* signal */
 #if 1
     if(main_sync_tic == current_sync_tic){
@@ -2897,6 +2911,10 @@ ags_thread_loop(void *ptr)
     ags_main_loop_set_syncing(AGS_MAIN_LOOP(main_loop), FALSE);
       
     g_rec_mutex_unlock(tree_mutex);
+
+    if(main_loop != NULL){
+      g_object_unref(main_loop);
+    }
   }
   
   /* exit thread */
